count_layout_mismatches

Function count_layout_mismatches 

pub fn count_layout_mismatches(module: &Module) -> usize
Counts the number of layout mismatches between global variables.

A mismatch occurs when two globals that feed into the same operation have different layouts. This is useful for diagnostics.