pub fn count_layout_mismatches(module: &Module) -> usizeExpand description
Counts the number of layout mismatches between global variables.
A mismatch occurs when two globals that feed into the same operation have different layouts. This is useful for diagnostics.